pre {
  line-height: 125%;
}

td.linenos .normal {
  color: inherit;
  background-color: transparent;
  padding-left: 5px;
  padding-right: 5px;
}

span.linenos {
  color: inherit;
  background-color: transparent;
  padding-left: 5px;
  padding-right: 5px;
}

td.linenos .special {
  color: #000000;
  background-color: #ffffc0;
  padding-left: 5px;
  padding-right: 5px;
}

span.linenos.special {
  color: #000000;
  background-color: #ffffc0;
  padding-left: 5px;
  padding-right: 5px;
}

.highlight .hll {
  background-color: #ffffcc;
}

.highlight {
  background: #f8f8f8;
}

.highlight .c {
  color: #3D7B7B;
  font-style: italic;
}

/* Comment */
.highlight .err {
  border: 1px solid #FF0000;
}

/* Error */
.highlight .k {
  color: #008000;
  font-weight: bold;
}

/* Keyword */
.highlight .o {
  color: #666666;
}

/* Operator */
.highlight .ch {
  color: #3D7B7B;
  font-style: italic;
}

/* Comment.Hashbang */
.highlight .cm {
  color: #3D7B7B;
  font-style: italic;
}

/* Comment.Multiline */
.highlight .cp {
  color: #9C6500;
}

/* Comment.Preproc */
.highlight .cpf {
  color: #3D7B7B;
  font-style: italic;
}

/* Comment.PreprocFile */
.highlight .c1 {
  color: #3D7B7B;
  font-style: italic;
}

/* Comment.Single */
.highlight .cs {
  color: #3D7B7B;
  font-style: italic;
}

/* Comment.Special */
.highlight .gd {
  color: #A00000;
}

/* Generic.Deleted */
.highlight .ge {
  font-style: italic;
}

/* Generic.Emph */
.highlight .gr {
  color: #E40000;
}

/* Generic.Error */
.highlight .gh {
  color: #000080;
  font-weight: bold;
}

/* Generic.Heading */
.highlight .gi {
  color: #008400;
}

/* Generic.Inserted */
.highlight .go {
  color: #717171;
}

/* Generic.Output */
.highlight .gp {
  color: #000080;
  font-weight: bold;
}

/* Generic.Prompt */
.highlight .gs {
  font-weight: bold;
}

/* Generic.Strong */
.highlight .gu {
  color: #800080;
  font-weight: bold;
}

/* Generic.Subheading */
.highlight .gt {
  color: #0044DD;
}

/* Generic.Traceback */
.highlight .kc {
  color: #008000;
  font-weight: bold;
}

/* Keyword.Constant */
.highlight .kd {
  color: #008000;
  font-weight: bold;
}

/* Keyword.Declaration */
.highlight .kn {
  color: #008000;
  font-weight: bold;
}

/* Keyword.Namespace */
.highlight .kp {
  color: #008000;
}

/* Keyword.Pseudo */
.highlight .kr {
  color: #008000;
  font-weight: bold;
}

/* Keyword.Reserved */
.highlight .kt {
  color: #B00040;
}

/* Keyword.Type */
.highlight .m {
  color: #666666;
}

/* Literal.Number */
.highlight .s {
  color: #BA2121;
}

/* Literal.String */
.highlight .na {
  color: #687822;
}

/* Name.Attribute */
.highlight .nb {
  color: #008000;
}

/* Name.Builtin */
.highlight .nc {
  color: #0000FF;
  font-weight: bold;
}

/* Name.Class */
.highlight .no {
  color: #880000;
}

/* Name.Constant */
.highlight .nd {
  color: #AA22FF;
}

/* Name.Decorator */
.highlight .ni {
  color: #717171;
  font-weight: bold;
}

/* Name.Entity */
.highlight .ne {
  color: #CB3F38;
  font-weight: bold;
}

/* Name.Exception */
.highlight .nf {
  color: #0000FF;
}

/* Name.Function */
.highlight .nl {
  color: #767600;
}

/* Name.Label */
.highlight .nn {
  color: #0000FF;
  font-weight: bold;
}

/* Name.Namespace */
.highlight .nt {
  color: #008000;
  font-weight: bold;
}

/* Name.Tag */
.highlight .nv {
  color: #19177C;
}

/* Name.Variable */
.highlight .ow {
  color: #AA22FF;
  font-weight: bold;
}

/* Operator.Word */
.highlight .w {
  color: #bbbbbb;
}

/* Text.Whitespace */
.highlight .mb {
  color: #666666;
}

/* Literal.Number.Bin */
.highlight .mf {
  color: #666666;
}

/* Literal.Number.Float */
.highlight .mh {
  color: #666666;
}

/* Literal.Number.Hex */
.highlight .mi {
  color: #666666;
}

/* Literal.Number.Integer */
.highlight .mo {
  color: #666666;
}

/* Literal.Number.Oct */
.highlight .sa {
  color: #BA2121;
}

/* Literal.String.Affix */
.highlight .sb {
  color: #BA2121;
}

/* Literal.String.Backtick */
.highlight .sc {
  color: #BA2121;
}

/* Literal.String.Char */
.highlight .dl {
  color: #BA2121;
}

/* Literal.String.Delimiter */
.highlight .sd {
  color: #BA2121;
  font-style: italic;
}

/* Literal.String.Doc */
.highlight .s2 {
  color: #BA2121;
}

/* Literal.String.Double */
.highlight .se {
  color: #AA5D1F;
  font-weight: bold;
}

/* Literal.String.Escape */
.highlight .sh {
  color: #BA2121;
}

/* Literal.String.Heredoc */
.highlight .si {
  color: #A45A77;
  font-weight: bold;
}

/* Literal.String.Interpol */
.highlight .sx {
  color: #008000;
}

/* Literal.String.Other */
.highlight .sr {
  color: #A45A77;
}

/* Literal.String.Regex */
.highlight .s1 {
  color: #BA2121;
}

/* Literal.String.Single */
.highlight .ss {
  color: #19177C;
}

/* Literal.String.Symbol */
.highlight .bp {
  color: #008000;
}

/* Name.Builtin.Pseudo */
.highlight .fm {
  color: #0000FF;
}

/* Name.Function.Magic */
.highlight .vc {
  color: #19177C;
}

/* Name.Variable.Class */
.highlight .vg {
  color: #19177C;
}

/* Name.Variable.Global */
.highlight .vi {
  color: #19177C;
}

/* Name.Variable.Instance */
.highlight .vm {
  color: #19177C;
}

/* Name.Variable.Magic */
.highlight .il {
  color: #666666;
}

/* Literal.Number.Integer.Long */
/*
 * basic.css
 * ~~~~~~~~~
 *
 * Sphinx stylesheet -- basic theme.
 *
 * :copyright: Copyright 2007-2022 by the Sphinx team, see AUTHORS.
 * :license: BSD, see LICENSE for details.
 *
 */
/* -- main layout ----------------------------------------------------------- */
.sphinxpage-body .wildewidgets_html_container {
  line-height: 1.5rem;
  font-size: 0.9rem;
  /* -- relbar ---------------------------------------------------------------- */
  /* -- sidebar --------------------------------------------------------------- */
  /* -- search page ----------------------------------------------------------- */
  /* -- index page ------------------------------------------------------------ */
  /* -- general index --------------------------------------------------------- */
  /* -- domain module index --------------------------------------------------- */
  /* -- general body styles --------------------------------------------------- */
  /* -- sidebars -------------------------------------------------------------- */
  /* -- topics ---------------------------------------------------------------- */
  /* -- admonitions ----------------------------------------------------------- */
  /* -- content of sidebars/topics/admonitions -------------------------------- */
  /* -- tables ---------------------------------------------------------------- */
  /* -- figures --------------------------------------------------------------- */
  /* -- field list styles ----------------------------------------------------- */
  /* -- hlist styles ---------------------------------------------------------- */
  /* -- object description styles --------------------------------------------- */
  /* C++ specific styling */
  /* -- other body styles ----------------------------------------------------- */
  /* -- code displays --------------------------------------------------------- */
  /* -- math display ---------------------------------------------------------- */
  /* -- printout stylesheet --------------------------------------------------- */
}
.sphinxpage-body .wildewidgets_html_container .clearer {
  clear: both;
}
.sphinxpage-body .wildewidgets_html_container .section::after {
  display: block;
  content: "";
  clear: left;
}
.sphinxpage-body .wildewidgets_html_container .related {
  width: 100%;
  font-size: 90%;
}
.sphinxpage-body .wildewidgets_html_container .related h3 {
  display: none;
}
.sphinxpage-body .wildewidgets_html_container .related ul {
  margin: 0;
  padding: 0 0 0 10px;
  list-style: none;
}
.sphinxpage-body .wildewidgets_html_container .related li {
  display: inline;
}
.sphinxpage-body .wildewidgets_html_container .related li.right {
  float: right;
  margin-right: 5px;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebarwrapper {
  padding: 10px 5px 0 10px;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar {
  float: left;
  width: 230px;
  margin-left: -100%;
  font-size: 90%;
  word-wrap: break-word;
  overflow-wrap: break-word;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar ul {
  list-style: none;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar ul ul,
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar ul.want-points {
  margin-left: 20px;
  list-style: square;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar ul ul {
  margin-top: 0;
  margin-bottom: 0;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar form {
  margin-top: 10px;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar input {
  border: 1px solid #98dbcc;
  font-family: sans-serif;
  font-size: 1em;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar #searchbox form.search {
  overflow: hidden;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar #searchbox input[type=text] {
  float: left;
  width: 80%;
  padding: 0.25em;
  box-sizing: border-box;
}
.sphinxpage-body .wildewidgets_html_container .sphinxsidebar #searchbox input[type=submit] {
  float: left;
  width: 20%;
  border-left: none;
  padding: 0.25em;
  box-sizing: border-box;
}
.sphinxpage-body .wildewidgets_html_container img {
  border: 0;
  max-width: 100%;
}
.sphinxpage-body .wildewidgets_html_container ul.search {
  margin: 10px 0 0 20px;
  padding: 0;
}
.sphinxpage-body .wildewidgets_html_container ul.search li {
  padding: 5px 0 5px 20px;
  background-image: url(file.png);
  background-repeat: no-repeat;
  background-position: 0 7px;
}
.sphinxpage-body .wildewidgets_html_container ul.search li a {
  font-weight: bold;
}
.sphinxpage-body .wildewidgets_html_container ul.search li p.context {
  color: #888;
  margin: 2px 0 0 30px;
  text-align: left;
}
.sphinxpage-body .wildewidgets_html_container ul.keywordmatches li.goodmatch a {
  font-weight: bold;
}
.sphinxpage-body .wildewidgets_html_container table.contentstable {
  width: 90%;
  margin-left: auto;
  margin-right: auto;
}
.sphinxpage-body .wildewidgets_html_container table.contentstable p.biglink {
  line-height: 150%;
}
.sphinxpage-body .wildewidgets_html_container a.biglink {
  font-size: 1.3em;
}
.sphinxpage-body .wildewidgets_html_container span.linkdescr {
  font-style: italic;
  padding-top: 5px;
  font-size: 90%;
}
.sphinxpage-body .wildewidgets_html_container table.indextable {
  width: 100%;
}
.sphinxpage-body .wildewidgets_html_container table.indextable td {
  text-align: left;
  vertical-align: top;
}
.sphinxpage-body .wildewidgets_html_container table.indextable ul {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
}
.sphinxpage-body .wildewidgets_html_container table.indextable > tbody > tr > td > ul {
  padding-left: 0em;
}
.sphinxpage-body .wildewidgets_html_container table.indextable tr.pcap {
  height: 10px;
}
.sphinxpage-body .wildewidgets_html_container table.indextable tr.cap {
  margin-top: 10px;
  background-color: #f2f2f2;
}
.sphinxpage-body .wildewidgets_html_container img.toggler {
  margin-right: 3px;
  margin-top: 3px;
  cursor: pointer;
}
.sphinxpage-body .wildewidgets_html_container .modindex-jumpbox {
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
  margin: 1em 0 1em 0;
  padding: 0.4em;
}
.sphinxpage-body .wildewidgets_html_container .genindex-jumpbox {
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
  margin: 1em 0 1em 0;
  padding: 0.4em;
}
.sphinxpage-body .wildewidgets_html_container table.modindextable td {
  padding: 2px;
  border-collapse: collapse;
}
.sphinxpage-body .wildewidgets_html_container .body {
  min-width: 360px;
  max-width: 800px;
}
.sphinxpage-body .wildewidgets_html_container .body p, .sphinxpage-body .wildewidgets_html_container .body dd, .sphinxpage-body .wildewidgets_html_container .body li, .sphinxpage-body .wildewidgets_html_container .body blockquote {
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  -webkit-hyphens: auto;
  hyphens: auto;
}
.sphinxpage-body .wildewidgets_html_container a.headerlink {
  visibility: hidden;
}
.sphinxpage-body .wildewidgets_html_container a.brackets:before,
.sphinxpage-body .wildewidgets_html_container span.brackets > a:before {
  content: "[";
}
.sphinxpage-body .wildewidgets_html_container a.brackets:after,
.sphinxpage-body .wildewidgets_html_container span.brackets > a:after {
  content: "]";
}
.sphinxpage-body .wildewidgets_html_container h1:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container h2:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container h3:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container h4:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container h5:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container h6:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container dt:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container caption:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container p.caption:hover > a.headerlink,
.sphinxpage-body .wildewidgets_html_container .code-block-caption:hover > a.headerlink {
  visibility: visible;
}
.sphinxpage-body .wildewidgets_html_container .body p.caption {
  text-align: inherit;
}
.sphinxpage-body .wildewidgets_html_container .body td {
  text-align: left;
}
.sphinxpage-body .wildewidgets_html_container .first {
  margin-top: 0 !important;
}
.sphinxpage-body .wildewidgets_html_container p.rubric {
  margin-top: 30px;
  font-weight: bold;
}
.sphinxpage-body .wildewidgets_html_container img.align-left, .sphinxpage-body .wildewidgets_html_container figure.align-left, .sphinxpage-body .wildewidgets_html_container .figure.align-left, .sphinxpage-body .wildewidgets_html_container object.align-left {
  clear: left;
  float: left;
  margin-right: 1em;
}
.sphinxpage-body .wildewidgets_html_container img.align-right, .sphinxpage-body .wildewidgets_html_container figure.align-right, .sphinxpage-body .wildewidgets_html_container .figure.align-right, .sphinxpage-body .wildewidgets_html_container object.align-right {
  clear: right;
  float: right;
  margin-left: 1em;
}
.sphinxpage-body .wildewidgets_html_container img.align-center, .sphinxpage-body .wildewidgets_html_container figure.align-center, .sphinxpage-body .wildewidgets_html_container .figure.align-center, .sphinxpage-body .wildewidgets_html_container object.align-center {
  display: block;
  margin-left: auto;
  margin-right: auto;
}
.sphinxpage-body .wildewidgets_html_container img.align-default, .sphinxpage-body .wildewidgets_html_container figure.align-default, .sphinxpage-body .wildewidgets_html_container .figure.align-default {
  display: block;
  margin-left: auto;
  margin-right: auto;
}
.sphinxpage-body .wildewidgets_html_container .align-left {
  text-align: left;
}
.sphinxpage-body .wildewidgets_html_container .align-center {
  text-align: center;
}
.sphinxpage-body .wildewidgets_html_container .align-default {
  text-align: center;
}
.sphinxpage-body .wildewidgets_html_container .align-right {
  text-align: right;
}
.sphinxpage-body .wildewidgets_html_container .sidebar,
.sphinxpage-body .wildewidgets_html_container aside.sidebar {
  margin: 0 0 0.5em 1em;
  border: 1px solid #ddb;
  padding: 7px;
  background-color: #ffe;
  width: 40%;
  float: right;
  clear: right;
  overflow-x: auto;
}
.sphinxpage-body .wildewidgets_html_container p.sidebar-title {
  font-weight: bold;
}
.sphinxpage-body .wildewidgets_html_container .admonition, .sphinxpage-body .wildewidgets_html_container .topic, .sphinxpage-body .wildewidgets_html_container blockquote {
  clear: left;
}
.sphinxpage-body .wildewidgets_html_container .topic {
  border: 1px solid #ccc;
  padding: 7px;
  margin: 10px 0 10px 0;
}
.sphinxpage-body .wildewidgets_html_container p.topic-title {
  font-size: 1.1em;
  font-weight: bold;
  margin-top: 10px;
}
.sphinxpage-body .wildewidgets_html_container .admonition {
  padding: 12px;
  line-height: 24px;
  margin-top: 2.5rem;
  margin-bottom: 2.5rem;
  background: #e7f2fa;
  border-radius: 5px;
}
.sphinxpage-body .wildewidgets_html_container .admonition dt {
  font-weight: bold;
}
.sphinxpage-body .wildewidgets_html_container p.admonition-title {
  border-top-left-radius: 5px;
  border-top-right-radius: 5px;
  font-weight: 700;
  display: block;
  color: #fff;
  background: #6ab0de;
  padding: 6px 12px;
  margin: -12px -12px 12px;
}
.sphinxpage-body .wildewidgets_html_container .admonition-todo {
  background-color: #ffedcc;
}
.sphinxpage-body .wildewidgets_html_container .admonition-todo .admonition-title {
  background-color: #f0b37e;
}
.sphinxpage-body .wildewidgets_html_container .admonition.danger {
  background-color: #fdf3f2;
}
.sphinxpage-body .wildewidgets_html_container .admonition.danger .admonition-title {
  background-color: #f29f97;
}
.sphinxpage-body .wildewidgets_html_container .admonition.note {
  background-color: #e7f2fa;
}
.sphinxpage-body .wildewidgets_html_container .admonition.note .admonition-title {
  background-color: #6ab0de;
}
.sphinxpage-body .wildewidgets_html_container .admonition.hint {
  background-color: #dbfaf4;
}
.sphinxpage-body .wildewidgets_html_container .admonition.hint .admonition-title {
  background-color: #1abc9c;
}
.sphinxpage-body .wildewidgets_html_container .body p.centered {
  text-align: center;
  margin-top: 25px;
}
.sphinxpage-body .wildewidgets_html_container .sidebar > :last-child,
.sphinxpage-body .wildewidgets_html_container aside.sidebar > :last-child,
.sphinxpage-body .wildewidgets_html_container .topic > :last-child,
.sphinxpage-body .wildewidgets_html_container .admonition > :last-child {
  margin-bottom: 0;
}
.sphinxpage-body .wildewidgets_html_container .sidebar::after,
.sphinxpage-body .wildewidgets_html_container aside.sidebar::after,
.sphinxpage-body .wildewidgets_html_container .topic::after,
.sphinxpage-body .wildewidgets_html_container .admonition::after,
.sphinxpage-body .wildewidgets_html_container blockquote::after {
  display: block;
  content: "";
  clear: both;
}
.sphinxpage-body .wildewidgets_html_container table.docutils {
  margin-top: 10px;
  margin-bottom: 10px;
  border: 0;
  border-collapse: collapse;
}
.sphinxpage-body .wildewidgets_html_container table.align-center {
  margin-left: auto;
  margin-right: auto;
}
.sphinxpage-body .wildewidgets_html_container table.align-default {
  margin-left: auto;
  margin-right: auto;
}
.sphinxpage-body .wildewidgets_html_container table caption span.caption-number {
  font-style: italic;
}
.sphinxpage-body .wildewidgets_html_container table.docutils td, .sphinxpage-body .wildewidgets_html_container table.docutils th {
  padding: 1px 8px 1px 5px;
  border-top: 0;
  border-left: 0;
  border-right: 0;
  border-bottom: 1px solid #aaa;
}
.sphinxpage-body .wildewidgets_html_container th {
  text-align: left;
  padding-right: 5px;
}
.sphinxpage-body .wildewidgets_html_container table.citation {
  border-left: solid 1px gray;
  margin-left: 1px;
}
.sphinxpage-body .wildewidgets_html_container table.citation td {
  border-bottom: none;
}
.sphinxpage-body .wildewidgets_html_container th > :first-child,
.sphinxpage-body .wildewidgets_html_container td > :first-child {
  margin-top: 0px;
}
.sphinxpage-body .wildewidgets_html_container th > :last-child,
.sphinxpage-body .wildewidgets_html_container td > :last-child {
  margin-bottom: 0px;
}
.sphinxpage-body .wildewidgets_html_container .figure, .sphinxpage-body .wildewidgets_html_container figure {
  margin: 0.5em;
  padding: 0.5em;
}
.sphinxpage-body .wildewidgets_html_container .figure p.caption, .sphinxpage-body .wildewidgets_html_container figcaption {
  padding: 0.3em;
}
.sphinxpage-body .wildewidgets_html_container .figure p.caption span.caption-number,
.sphinxpage-body .wildewidgets_html_container figcaption span.caption-number {
  font-style: italic;
}
.sphinxpage-body .wildewidgets_html_container table.field-list td, .sphinxpage-body .wildewidgets_html_container table.field-list th {
  border: 0 !important;
}
.sphinxpage-body .wildewidgets_html_container .field-list ul {
  margin: 0;
  padding-left: 1em;
}
.sphinxpage-body .wildewidgets_html_container .field-list p {
  margin: 0;
}
.sphinxpage-body .wildewidgets_html_container .field-name {
  -moz-hyphens: manual;
  -ms-hyphens: manual;
  -webkit-hyphens: manual;
  hyphens: manual;
}
.sphinxpage-body .wildewidgets_html_container table.hlist {
  margin: 1em 0;
}
.sphinxpage-body .wildewidgets_html_container table.hlist td {
  vertical-align: top;
}
.sphinxpage-body .wildewidgets_html_container .sig {
  font-family: "Consolas", "Menlo", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", monospace;
}
.sphinxpage-body .wildewidgets_html_container .sig-name, .sphinxpage-body .wildewidgets_html_container code.descname {
  background-color: transparent;
  font-weight: bold;
}
.sphinxpage-body .wildewidgets_html_container .sig-name {
  font-size: 1.1em;
}
.sphinxpage-body .wildewidgets_html_container code.descname {
  font-size: 1.2em;
}
.sphinxpage-body .wildewidgets_html_container .sig-prename, .sphinxpage-body .wildewidgets_html_container code.descclassname {
  background-color: transparent;
}
.sphinxpage-body .wildewidgets_html_container .optional {
  font-size: 1.3em;
}
.sphinxpage-body .wildewidgets_html_container .sig-paren {
  font-size: larger;
}
.sphinxpage-body .wildewidgets_html_container .sig-param.n {
  font-style: italic;
}
.sphinxpage-body .wildewidgets_html_container .sig-inline.c-texpr,
.sphinxpage-body .wildewidgets_html_container .sig-inline.cpp-texpr {
  font-family: unset;
}
.sphinxpage-body .wildewidgets_html_container .sig.c .k, .sphinxpage-body .wildewidgets_html_container .sig.c .kt,
.sphinxpage-body .wildewidgets_html_container .sig.cpp .k, .sphinxpage-body .wildewidgets_html_container .sig.cpp .kt {
  color: #0033B3;
}
.sphinxpage-body .wildewidgets_html_container .sig.c .m,
.sphinxpage-body .wildewidgets_html_container .sig.cpp .m {
  color: #1750EB;
}
.sphinxpage-body .wildewidgets_html_container .sig.c .s, .sphinxpage-body .wildewidgets_html_container .sig.c .sc,
.sphinxpage-body .wildewidgets_html_container .sig.cpp .s, .sphinxpage-body .wildewidgets_html_container .sig.cpp .sc {
  color: #067D17;
}
.sphinxpage-body .wildewidgets_html_container ol.arabic {
  list-style: decimal;
}
.sphinxpage-body .wildewidgets_html_container ol.loweralpha {
  list-style: lower-alpha;
}
.sphinxpage-body .wildewidgets_html_container ol.upperalpha {
  list-style: upper-alpha;
}
.sphinxpage-body .wildewidgets_html_container ol.lowerroman {
  list-style: lower-roman;
}
.sphinxpage-body .wildewidgets_html_container ol.upperroman {
  list-style: upper-roman;
}
.sphinxpage-body .wildewidgets_html_container :not(li) > ol > li:first-child > :first-child,
.sphinxpage-body .wildewidgets_html_container :not(li) > ul > li:first-child > :first-child {
  margin-top: 0px;
}
.sphinxpage-body .wildewidgets_html_container :not(li) > ol > li:last-child > :last-child,
.sphinxpage-body .wildewidgets_html_container :not(li) > ul > li:last-child > :last-child {
  margin-bottom: 0px;
}
.sphinxpage-body .wildewidgets_html_container ol.simple ol p,
.sphinxpage-body .wildewidgets_html_container ol.simple ul p,
.sphinxpage-body .wildewidgets_html_container ul.simple ol p,
.sphinxpage-body .wildewidgets_html_container ul.simple ul p {
  margin-top: 0;
}
.sphinxpage-body .wildewidgets_html_container ol.simple li,
.sphinxpage-body .wildewidgets_html_container ul.simple li {
  margin-bottom: 0.5rem;
}
.sphinxpage-body .wildewidgets_html_container ol.simple > li:not(:first-child) > p,
.sphinxpage-body .wildewidgets_html_container ul.simple > li:not(:first-child) > p {
  margin-top: 0;
}
.sphinxpage-body .wildewidgets_html_container ol.simple p,
.sphinxpage-body .wildewidgets_html_container ul.simple p {
  margin-bottom: 0;
}
.sphinxpage-body .wildewidgets_html_container dl.footnote > dt,
.sphinxpage-body .wildewidgets_html_container dl.citation > dt {
  float: left;
  margin-right: 0.5em;
}
.sphinxpage-body .wildewidgets_html_container dl.footnote > dd,
.sphinxpage-body .wildewidgets_html_container dl.citation > dd {
  margin-bottom: 0em;
}
.sphinxpage-body .wildewidgets_html_container dl.footnote > dd:after,
.sphinxpage-body .wildewidgets_html_container dl.citation > dd:after {
  content: "";
  clear: both;
}
.sphinxpage-body .wildewidgets_html_container dl.field-list {
  display: grid;
  grid-template-columns: fit-content(30%) auto;
}
.sphinxpage-body .wildewidgets_html_container dl.field-list > dt {
  font-weight: bold;
  word-break: break-word;
  padding-left: 0.5em;
  padding-right: 5px;
}
.sphinxpage-body .wildewidgets_html_container dl.field-list > dt:after {
  content: ":";
}
.sphinxpage-body .wildewidgets_html_container dl.field-list > dd {
  padding-left: 0.5em;
  margin-top: 0em;
  margin-left: 0em;
  margin-bottom: 0em;
}
.sphinxpage-body .wildewidgets_html_container dl {
  margin-bottom: 15px;
}
.sphinxpage-body .wildewidgets_html_container dd > :first-child {
  margin-top: 0px;
}
.sphinxpage-body .wildewidgets_html_container dd ul, .sphinxpage-body .wildewidgets_html_container dd table {
  margin-bottom: 10px;
}
.sphinxpage-body .wildewidgets_html_container dd {
  margin-top: 3px;
  margin-bottom: 10px;
  margin-left: 30px;
}
.sphinxpage-body .wildewidgets_html_container dl > dd:last-child,
.sphinxpage-body .wildewidgets_html_container dl > dd:last-child > :last-child {
  margin-bottom: 0;
}
.sphinxpage-body .wildewidgets_html_container dt:target, .sphinxpage-body .wildewidgets_html_container span.highlighted {
  background-color: #fbe54e;
}
.sphinxpage-body .wildewidgets_html_container rect.highlighted {
  fill: #fbe54e;
}
.sphinxpage-body .wildewidgets_html_container dl.glossary dt {
  font-weight: bold;
  font-size: 1.1em;
}
.sphinxpage-body .wildewidgets_html_container .versionmodified {
  font-style: italic;
}
.sphinxpage-body .wildewidgets_html_container .system-message {
  background-color: #fda;
  padding: 5px;
  border: 3px solid red;
}
.sphinxpage-body .wildewidgets_html_container .footnote:target {
  background-color: #ffa;
}
.sphinxpage-body .wildewidgets_html_container .line-block {
  display: block;
  margin-top: 1em;
  margin-bottom: 1em;
}
.sphinxpage-body .wildewidgets_html_container .line-block .line-block {
  margin-top: 0;
  margin-bottom: 0;
  margin-left: 1.5em;
}
.sphinxpage-body .wildewidgets_html_container .guilabel, .sphinxpage-body .wildewidgets_html_container .menuselection {
  font-family: sans-serif;
}
.sphinxpage-body .wildewidgets_html_container .accelerator {
  text-decoration: underline;
}
.sphinxpage-body .wildewidgets_html_container .classifier {
  font-style: oblique;
}
.sphinxpage-body .wildewidgets_html_container .classifier:before {
  font-style: normal;
  margin: 0 0.5em;
  content: ":";
  display: inline-block;
}
.sphinxpage-body .wildewidgets_html_container abbr, .sphinxpage-body .wildewidgets_html_container acronym {
  border-bottom: dotted 1px;
  cursor: help;
}
.sphinxpage-body .wildewidgets_html_container pre {
  overflow: auto;
  overflow-y: hidden;
  /* fixes display issues on Chrome browsers */
}
.sphinxpage-body .wildewidgets_html_container pre, .sphinxpage-body .wildewidgets_html_container [class*=highlight-] {
  clear: both;
}
.sphinxpage-body .wildewidgets_html_container span.pre {
  -moz-hyphens: none;
  -ms-hyphens: none;
  -webkit-hyphens: none;
  hyphens: none;
  white-space: nowrap;
}
.sphinxpage-body .wildewidgets_html_container [class*=highlight-] {
  margin: 1em 0;
}
.sphinxpage-body .wildewidgets_html_container td.linenos pre {
  border: 0;
  background-color: transparent;
  color: #aaa;
}
.sphinxpage-body .wildewidgets_html_container table.highlighttable {
  display: block;
}
.sphinxpage-body .wildewidgets_html_container table.highlighttable tbody {
  display: block;
}
.sphinxpage-body .wildewidgets_html_container table.highlighttable tr {
  display: flex;
}
.sphinxpage-body .wildewidgets_html_container table.highlighttable td {
  margin: 0;
  padding: 0;
}
.sphinxpage-body .wildewidgets_html_container table.highlighttable td.linenos {
  padding-right: 0.5em;
}
.sphinxpage-body .wildewidgets_html_container table.highlighttable td.code {
  flex: 1;
  overflow: hidden;
}
.sphinxpage-body .wildewidgets_html_container .highlight .hll {
  display: block;
}
.sphinxpage-body .wildewidgets_html_container .highlight pre,
.sphinxpage-body .wildewidgets_html_container table.highlighttable pre {
  margin: 0;
}
.sphinxpage-body .wildewidgets_html_container .code-block-caption + {
  margin-top: 0;
}
.sphinxpage-body .wildewidgets_html_container .code-block-caption {
  margin-top: 1em;
  padding: 2px 5px;
  font-size: small;
}
.sphinxpage-body .wildewidgets_html_container .code-block-caption code {
  background-color: transparent;
}
.sphinxpage-body .wildewidgets_html_container table.highlighttable td.linenos,
.sphinxpage-body .wildewidgets_html_container span.linenos,
.sphinxpage-body .wildewidgets_html_container .highlight span.gp {
  /* gp: Generic.Prompt */
  user-select: none;
  -webkit-user-select: text;
  /* Safari fallback only */
  -webkit-user-select: none;
  /* Chrome/Safari */
  -moz-user-select: none;
  /* Firefox */
  -ms-user-select: none;
  /* IE10+ */
}
.sphinxpage-body .wildewidgets_html_container .code-block-caption span.caption-number {
  padding: 0.1em 0.3em;
  font-style: italic;
}
.sphinxpage-body .wildewidgets_html_container .literal-block-wrapper {
  margin: 1em 0;
}
.sphinxpage-body .wildewidgets_html_container code.xref, .sphinxpage-body .wildewidgets_html_container a code {
  background-color: transparent;
  font-weight: bold;
}
.sphinxpage-body .wildewidgets_html_container h1 code, .sphinxpage-body .wildewidgets_html_container h2 code, .sphinxpage-body .wildewidgets_html_container h3 code, .sphinxpage-body .wildewidgets_html_container h4 code, .sphinxpage-body .wildewidgets_html_container h5 code, .sphinxpage-body .wildewidgets_html_container h6 code {
  background-color: transparent;
}
.sphinxpage-body .wildewidgets_html_container .viewcode-back {
  float: right;
  font-family: sans-serif;
}
.sphinxpage-body .wildewidgets_html_container .viewcode-block:target {
  margin: -1px -10px;
  padding: 0 10px;
}
.sphinxpage-body .wildewidgets_html_container img.math {
  vertical-align: middle;
}
.sphinxpage-body .wildewidgets_html_container .body .math p {
  text-align: center;
}
.sphinxpage-body .wildewidgets_html_container span.eqno {
  float: right;
}
.sphinxpage-body .wildewidgets_html_container span.eqno a.headerlink {
  position: absolute;
  z-index: 1;
}
.sphinxpage-body .wildewidgets_html_container .math:hover a.headerlink {
  visibility: visible;
}
@media print {
  .sphinxpage-body .wildewidgets_html_container .document,
.sphinxpage-body .wildewidgets_html_container .documentwrapper,
.sphinxpage-body .wildewidgets_html_container .bodywrapper {
    margin: 0 !important;
    width: 100%;
  }
  .sphinxpage-body .wildewidgets_html_container .sphinxsidebar,
.sphinxpage-body .wildewidgets_html_container .related,
.sphinxpage-body .wildewidgets_html_container .footer,
.sphinxpage-body .wildewidgets_html_container #top-link {
    display: none;
  }
}

.classifiers__filter__form a.nav-link-toggle {
  font-weight: bold;
  color: rgba(var(--tblr-blue-rgb), 1) !important;
}
.classifiers__filter__form ul {
  position: relative;
  padding: 0 0 0 5px;
  margin: 5px 0 0 12px;
}
.classifiers__filter__form ul > li:last-child::after {
  height: 13px;
}
.classifiers__filter__form li {
  padding: 0 0 0 5px;
  list-style: none;
  position: relative;
}
.classifiers__filter__form li .form-check {
  margin-bottom: 0;
}
.classifiers__filter__form li::after {
  border-left: 2px solid #bbb;
  content: "";
  height: 100%;
  left: -12px;
  position: absolute;
  top: -2px;
  width: 0;
}
.classifiers__filter__form li::before {
  border-top: 2px solid #bbb;
  content: "";
  height: 0;
  left: -12px;
  position: absolute;
  top: 10px;
  width: 12px;
}

pre {
  background-color: #f8f8f8;
  border: 1px solid #ccc;
  color: black;
}

.toc__toggle[aria-expanded=true] {
  transform: rotate(180deg);
}

.docutils.literal {
  font-size: small;
}

.sphinxpage-body tt, .sphinxpage-body code {
  white-space: nowrap;
  max-width: 100%;
  background: #fff;
  border: 1px solid #e1e4e5;
  font-size: 75%;
  padding: 0 5px;
  font-family: SFMono-Regular, Menlo, Monaco, Consolas, Liberation Mono, Courier New, Courier, monospace;
  color: #333;
  overflow-x: auto;
}
.sphinxpage-body h1 {
  margin-bottom: 2rem;
}
.sphinxpage-body h2 {
  margin-bottom: 1.2rem;
  margin-top: 1.5rem;
}
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt::before {
  color: #6ab0de;
}
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt {
  display: table;
  margin: 6px 0;
  font-size: 90%;
  line-height: normal;
  background: #e7f2fa;
  color: #2980b9;
  border-top: 3px solid #6ab0de;
  padding: 6px;
  position: relative;
}
.sphinxpage-body dl dd {
  margin: 0 0 12px 24px;
  line-height: 24px;
}
.sphinxpage-body dl dt {
  font-weight: 700;
  margin-bottom: 12px;
}
.sphinxpage-body dl.field-list,
.sphinxpage-body dl.footnote {
  display: grid;
  grid-template-columns: max-content auto;
}
.sphinxpage-body dl.field-list dd, .sphinxpage-body dl.field-list dt,
.sphinxpage-body dl.footnote dd,
.sphinxpage-body dl.footnote dt {
  margin-bottom: 0;
}
.sphinxpage-body dl.field-list dt,
.sphinxpage-body dl.footnote dt {
  padding-left: 1rem;
}
.sphinxpage-body dl.field-list dt::after,
.sphinxpage-body dl.footnote dt::after {
  content: ":";
}
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) {
  margin-bottom: 24px;
}
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) > dt:first-child {
  margin-top: 0;
}
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) .property {
  display: inline-block;
  padding-right: 8px;
  max-width: 100%;
}
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) dl:not(.field-list) > dt {
  margin-bottom: 6px;
  border: none;
  border-left: 3px solid #ccc;
  background: #f0f0f0;
  color: #555;
}
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) .descclassname,
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) .descname,
.sphinxpage-body dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) .sig-name {
  color: #000;
}
.sphinxpage-body .viewcode-back,
.sphinxpage-body .viewcode-link {
  display: inline-block;
  color: #27ae60;
  font-size: 80%;
  padding-left: 24px;
}
