# Generated by Django 4.1.7 on 2023-05-03 17:01

from django.db import migrations, models
import sphinx_hosting.fields


class Migration(migrations.Migration):

    dependencies = [
        ('sphinxhostingcore', '0010_add_groups'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='machine_name',
            field=sphinx_hosting.fields.MachineNameField(help_text='Must be unique.  Set this to the slugified value of "project" in Sphinx\'s. conf.py', unique=True, verbose_name='Machine Name'),
        ),
        migrations.AlterField(
            model_name='sphinxpage',
            name='orig_body',
            field=models.TextField(blank=True, help_text='The original body for the page, extracted from the page JSON. Some pages have no body. We save this here in case we need to reprocess the body at some later date.', verbose_name='Body (Original)'),
        ),
    ]
