# Generated by Django 4.1.2 on 2023-02-04 01:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sphinxhostingcore', '0008_Version_archived'),
    ]

    operations = [
        migrations.AddField(
            model_name='sphinxpage',
            name='searchable',
            field=models.BooleanField(default=False, help_text='Should this page be included in the search index?', verbose_name='Searchable'),
        ),
        migrations.AlterField(
            model_name='sphinxpage',
            name='orig_body',
            field=models.TextField(blank=True, help_text='The original body for the page, extracted from the page JSON. Some pages have no body.We save this here in case we need to reprocess the body at some later date.', verbose_name='Body (Original)'),
        ),
    ]
